#!/usr/bin/env python3


import argparse
import configparser
import sys
import os
import pathlib
import statsd
import inspect
from io import StringIO
from datetime import datetime

def _import_apcommon_path(apcommon):
    # Need to find and add relative ../apcommon dir to path to import apsdk et al
    # TODO: Find a better way to do this. Hint: Can also just wrap with start.sh
    common_path = os.path.realpath(
        os.path.abspath(
            os.path.join(
                os.path.split(
                    inspect.getfile(
                        inspect.currentframe()))[0], apcommon)))
    if common_path not in sys.path:
        sys.path.insert(0, common_path)

_import_apcommon_path('../apcommon')

from apsdk import env

def check_if_first_run(dummy_file):
    if (os.path.isfile(dummy_file)):
        print ("\nExiting since firstrun file already exists")
        sys.exit(os.EX_OK)

def write_dummy_file(dummy_file):
    #Creates dummy file so that this service only configures things on initial
    #system boot
    print ("\nCreating firstrun file so service doesn't run again")
    os.mknod(dummy_file)

def configure_autopilot_ini():
    autopilot_ini_path = env.get_autopilot_ini_path()
    autopilot_ini_temp_path = env.get_autopilot_ini_tmp_path()
    autopilot_ini_config = env.load_ini_file(autopilot_ini_path)

    linux_bootstrap_ini_path = env.get_linux_bootstrap_ini_path()
    linux_bootstrap_ini_config = env.load_ini_file(linux_bootstrap_ini_path)

    autopilot_ini_config = env.set_ini_value(autopilot_ini_config,'FILES','Environment',linux_bootstrap_ini_config['Config']['AutopilotEnvironment'])
    autopilot_ini_config = env.set_ini_value(autopilot_ini_config,'FILES','Cluster',linux_bootstrap_ini_config['Config']['AutopilotCluster'])
    autopilot_ini_config = env.set_ini_value(autopilot_ini_config,'APCA','Vip',linux_bootstrap_ini_config['Config']['AutopilotAPCAVip'])

    env.write_ini_file(autopilot_ini_temp_path,autopilot_ini_config)

    try:
        test = env.load_ini_file(autopilot_ini_temp_path)
    except:
        print ("\nCould not load autopilot.ini.tmp due to parsing error")
        sys.exit(os.EX_OSFILE)

    print ("\nautopilot.ini.tmp Test PASSED")
    print ("\nMoving: " + autopilot_ini_temp_path + " to: " + autopilot_ini_path)
    try:
        os.replace(autopilot_ini_temp_path, autopilot_ini_path)
    except:
        print ("\nCould not move autopilot.ini.tmp to autopilot.ini due to os.replace error")
        sys.exit(os.EX_OSFILE)

#def configure_timesyncd_conf():
#    linux_bootstrap_ini_path = env.get_linux_bootstrap_ini_path()
#    linux_bootstrap_ini_config = env.load_ini_file(linux_bootstrap_ini_path)
#
#    config_line = env.get_ini_value(linux_bootstrap_ini_config,'Config','AutopilotProvisioningServers')
#    ntp_servers = [x.strip() for x in config_line.split(',')]
#    new_config_line = ' '.join(ntp_servers)
#
#    config = configparser.ConfigParser()
#    config.optionxform = str
#    config.add_section('Time')
#    config.set('Time','NTP',new_config_line)
#
#    conf_filepath = "/etc/systemd/timesyncd.conf.d/timesyncd.conf"
#    env.write_ini_file(conf_filepath,config)

def main():
    print ("\nSTARTING")
    dummy_file = env.get_data_root() + "/apbootstrap/firstrun"
    check_if_first_run(dummy_file)

    configure_autopilot_ini()

#    configure_timesyncd_conf() 
    
    write_dummy_file(dummy_file)
    sys.exit(os.EX_OK)

if __name__ == '__main__':
    main()


