__author__ = "Kevin Tegtmeier"
__copyright__ = "Copyright (C) Microsoft. All rights reserved."


import os
import subprocess

class filesystem(object):
    """ Wraps all file system calls for interacting with directories and overlays """

    @classmethod
    def unmount_overlay(cls, target):
        """ Unmount the overlay. """
        #TODO: parse output.  (will make more robust when srevicemanagers consumes this)
        subprocess.check_call(["/bin/umount", target])

    @classmethod
    def mount_overlay(cls, lower, upper, target, mode):
        """ Perform overlay mount with sane defaults. """
        workdir = target + ".work"

        if not cls.isdir(target):
            os.makedirs(target)
        if not cls.isdir(workdir):
            os.makedirs(workdir)

        # TODO:  parse output.  handle non-root user.
        subprocess.check_call("/bin/mount -t overlayfs -o".split(" ") +
                               ["%s,lowerdir=%s,upperdir=%s,workdir=%s" % (mode, lower, upper, workdir),
                               "overlayfs",
                               "%s" % target])

    @classmethod
    def mounts(cls):
        return subprocess.check_output(["/bin/mount", "-t", "overlayfs"]).decode("utf-8")

    @classmethod
    def isdir(cls, d):
        """ Maps to os.path.isdir """
        return os.path.isdir(d)
