__author__ = "Kevin Tegtmeier"
__copyright__ = "Copyright (C) Microsoft. All rights reserved."

import subprocess
from subprocess import CalledProcessError


class SystemctlCmd:
    """
    Basic systemctl cli proxy.  Provides some sane defaults for text
    output format to fascilitate scripting.
    """

    def __init__(self):
        pass

    @classmethod
    def list_units(self, options=""):
        return subprocess.check_output(["/bin/systemctl",
                                        "list-units",
                                        "--no-legend"] + options.split()).decode("utf-8")

    @classmethod
    def start_unit(self, unitname):
        return self.__run_systemctl_call("start", unitname)

    @classmethod
    def stop_unit(self, unitname):
        return self.__run_systemctl_call("stop", unitname)

    @classmethod
    def reset_failed_unit(self, unitname):
        return self.__run_systemctl_call("reset-failed", unitname)

    @classmethod
    def enable_unit_file(self, unitfilepath):
        return self.__run_systemctl_call("enable", unitfilepath)

    @classmethod
    def link_unit_file(self, unitfilepath):
        """ Links unit file. (like enable but doesn't start) """
        return self.__run_systemctl_call("link", unitfilepath)

    @classmethod
    def disable_unit_file(self, unitfilepath):
        """ Reverses the link and enable actions """
        return self.__run_systemctl_call("disable", unitfilepath)

    @classmethod
    def __run_systemctl_call(self, command, arg):
        try:
            subprocess.check_call(["systemctl", command, arg])
            return True
        except CalledProcessError as e:
            print("Unable to execute systemctl %s %s.  Failed with %s"
                  % [command, arg, e.message])
        return False
