__author__ = "Kevin Tegtmeier"
__copyright__ = "Copyright (C) Microsoft. All rights reserved."

import os.path
from pysystemdwrapper.systemctl_cmd import SystemctlCmd


class UnitFile:
    """ Represents a systemd unit file """

    class NotFoundException(Exception):
        pass

    @classmethod
    def __fail_if_missing(self, path):
        if os.path.isfile(path):
            return
        raise UnitFile.NotFoundException(path)

    @classmethod
    def enable(self, path):
        self.__fail_if_missing(path)
        return SystemctlCmd.enable_unit_file(path)

    @classmethod
    def link(self, path):
        self.__fail_if_missing(path)
        return SystemctlCmd.link_unit_file(path)

    @classmethod
    def disable(self, path):
        self.__fail_if_missing(path)
        return SystemctlCmd.disable_unit_file(path)
